@@ -962,9 +962,17 @@ CameraDeselectedCallback = Union[
 
 
 # CoreManager
+class FfmpegArgs(TypedDict):
+    hwaccel: str
+    hwaccelArgs: list[str]
+    hwaccelFilter: str
+    threads: str
+
+
 @runtime_checkable
 class CoreManager(Protocol):
     async def get_ffmpeg_path(self) -> str: ...
+    async def get_hwaccel_info(self) -> FfmpegArgs: ...
     async def get_ice_servers(self) -> list[IceServer]: ...
     async def get_server_addresses(self) -> list[str]: ...
 
